@@ -27,8 +27,11 @@ from tensorflowjs.read_weights import read_weights
 from google.protobuf.json_format import ParseDict
 
 import tfjs_graph_converter.common as common
+from tfjs_graph_converter.common import CompatMode
 from tfjs_graph_converter.compat import convert_int64_to_int32
-from tfjs_graph_converter.convert_prelu import replace_prelu, split_fused_prelu
+from tfjs_graph_converter.convert_prelu import replace_prelu
+from tfjs_graph_converter.convert_prelu import split_all_fused_ops
+from tfjs_graph_converter.convert_prelu import split_fused_prelu
 from tfjs_graph_converter.convert_fused_depthwise import split_fused_depthwise
 from tfjs_graph_converter.graph_rewrite_util import validate_supported_ops
 from tfjs_graph_converter.graph_rewrite_util import harmonize_dtypes
@@ -235,11 +238,16 @@ def _create_graph(graph_def: GraphDef,
 
 
 def _replace_unsupported_operations(
-        input_graph_def: GraphDef) -> Tuple[GraphDef, Dict[str, Callable]]:
+        input_graph_def: GraphDef,
+        compat_mode: CompatMode = CompatMode.NONE
+        ) -> Tuple[GraphDef, Dict[str, Callable]]:
     """Replace known unsupported operations by rewriting the input graph"""
     weight_modifiers = dict()
-    # split fused ops that contain unsupported activations
-    new_graph, modifiers = split_fused_prelu(input_graph_def)
+    # split fused ops that contain unsupported activations or all fused ops
+    if compat_mode == CompatMode.TFLITE:
+        new_graph, modifiers = split_all_fused_ops(input_graph_def)
+    else:
+        new_graph, modifiers = split_fused_prelu(input_graph_def)
     weight_modifiers.update(modifiers)
     # split fused depthwise convolutions
     new_graph, modifiers = split_fused_depthwise(new_graph)
@@ -252,7 +260,7 @@ def _replace_unsupported_operations(
 
 def _convert_graph_model_to_graph(model_json: Dict[str, Any],
                                   base_path: str,
-                                  compat_mode: bool = False
+                                  compat_mode: CompatMode = CompatMode.NONE
                                   ) -> Tuple[tf.Graph, util.SignatureDef]:
     """
     Convert TFJS JSON model to TF Graph
@@ -260,7 +268,7 @@ def _convert_graph_model_to_graph(model_json: Dict[str, Any],
     Args:
         model_json: JSON dict from TFJS model file
         base_path:  Path to the model file (where to find the model weights)
-        compat_mode: True, if only TFJS datatypes should be used
+        compat_mode: Compatibility mode for model conversion and optimisation
 
     Returns:
         Tuple of TF Graph for inference or saving and TF signature definition
@@ -285,8 +293,9 @@ def _convert_graph_model_to_graph(model_json: Dict[str, Any],
     graph_def = _convert_graph_def(topology)
     name, data = common.TFJS_NAME_KEY, common.TFJS_DATA_KEY
     weight_dict = dict((weight[name], weight[data]) for weight in weight_list)
-    graph_def, weight_modifiers = _replace_unsupported_operations(graph_def)
-    if compat_mode:
+    graph_def, weight_modifiers = _replace_unsupported_operations(graph_def,
+                                                                  compat_mode)
+    if compat_mode == CompatMode.TFJS:
         graph_def = convert_int64_to_int32(graph_def)
     graph = _create_graph(graph_def, weight_dict, weight_modifiers)
     signature_def = _extract_signature_def(model_json) or util.infer_signature(
@@ -294,8 +303,41 @@ def _convert_graph_model_to_graph(model_json: Dict[str, Any],
     return _set_signature_dtypes(graph, signature_def)
 
 
+def enable_cuda():
+    """
+    Call this function *BEFORE* any tensorflow or tfjs_graph_converter function
+    to (re-)enable CUDA devices.
+
+    By default, CUDA devices are disabled when using tfjs_graph_converter to
+    ensure successful model conversion regardless of GPU capabilities and
+    available GPU memory.
+
+    If you need to use CUDA devices and tfjs_graph_converter simultaneously,
+    call this function right after importing tfjs_graph_converter:
+
+    ```
+    import tfjs_graph_converter as tfjs
+    import tensorflow as tf
+    tfjs.api.enable_cuda()
+
+
+    def main() -> None:
+        graph = tfjs.api.load_graph_model('models/tfjs_model')
+        model = tfjs.api.graph_to_function_v2(graph)
+        model_input = ...
+        # inference will run on the GPU if available
+        result = model(model_input)
+        ...
+
+    if __name__ == '__main__'
+        main()
+    ```
+    """
+    os.environ['CUDA_VISIBLE_DEVICES'] = ''
+
+
 def load_graph_model_and_signature(model_dir: str,
-                                   compat_mode: bool = False
+                                   compat_mode: CompatMode = CompatMode.NONE
                                    ) -> Tuple[tf.Graph, util.SignatureDef]:
     """
     Load a TFJS Graph Model from a directory
@@ -304,7 +346,7 @@ def load_graph_model_and_signature(model_dir: str,
         model_dir: Directory that contains the tfjs model.json and weights;
                 alternatively name and path of the model.json if the name
                 differs from the default ("model.json")
-        compat_mode: If True, only TFJS-compatible datatypes are used
+        compat_mode: Compatibility mode for model conversion and optimisation
 
     Returns:
         Tupel of TF frozen graph for inference or saving and TF signature def
@@ -316,7 +358,8 @@ def load_graph_model_and_signature(model_dir: str,
     return _convert_graph_model_to_graph(model_json, model_path, compat_mode)
 
 
-def load_graph_model(model_dir: str, compat_mode: bool = False) -> tf.Graph:
+def load_graph_model(model_dir: str,
+                     compat_mode: CompatMode = CompatMode.NONE) -> tf.Graph:
     """
     Load a TFJS Graph Model from a directory
 
@@ -324,7 +367,7 @@ def load_graph_model(model_dir: str, compat_mode: bool = False) -> tf.Graph:
         model_dir: Directory that contains the tfjs model.json and weights;
                 alternatively name and path of the model.json if the name
                 differs from the default ("model.json")
-        compat_mode: If True, only TFJS-compatible datatypes are used
+        compat_mode: Compatibility mode for model conversion and optimisation
 
     Returns:
         TF frozen graph for inference or saving
@@ -380,14 +423,15 @@ def graph_to_function_v2(graph: Union[GraphDef, tf.Graph]) -> Callable:
 
 
 def graph_model_to_frozen_graph(model_dir: str, export_path: str,
-                                compat_mode: bool = False) -> str:
+                                compat_mode: CompatMode = CompatMode.NONE
+                                ) -> str:
     """
     Convert a TFJS graph model to a frozen TF graph
 
     Args:
         model_dir: Directory that contains the TFJS JSON model and weights
         export_path: Path to the frozen graph (e.g. './output.pb')
-        compat_mode: If True, only TFJS-compatible datatypes are used
+        compat_mode: Compatibility mode for model conversion and optimisation
 
     Returns:
         The path to the output proto-file.
@@ -404,7 +448,8 @@ def graph_model_to_saved_model(model_dir: str,
                                tags: List[str] = None,
                                signature_def_map: dict = None,
                                signature_key_map: RenameMap = None,
-                               compat_mode: bool = False) -> str:
+                               compat_mode: CompatMode = CompatMode.NONE
+                               ) -> str:
     """
     Convert a TFJS graph model to a SavedModel
 
@@ -431,7 +476,7 @@ def graph_model_to_saved_model(model_dir: str,
                            keys. The default signature uses tensor names for
                            signature keys. This argument allows to map tensor
                            names to different keys.
-        compat_mode: If True, only TFJS-compatible datatypes are used
+        compat_mode: Compatibility mode for model conversion and optimisation
 
     Returns:
         The path to which the model was written.
@@ -455,7 +500,7 @@ def graph_models_to_saved_model(model_list: List[Tuple[str, List[str]]],
                                 export_dir: str,
                                 signatures: dict = None,
                                 signature_keys: Dict[str, RenameMap] = None,
-                                compat_mode: bool = False
+                                compat_mode: CompatMode = CompatMode.NONE
                                 ) -> str:
     """
     Read multiple TFJS graph models and saves them in a single SavedModel
@@ -485,7 +530,7 @@ def graph_models_to_saved_model(model_list: List[Tuple[str, List[str]]],
             `model_list` tuples) to per-model signature key mappings. This
             allows a remapping of signature inputs and outputs to different
             keys (the tensor names stay unaffected).
-        compat_mode: If True, only TFJS-compatible datatypes are used
+        compat_mode: Compatibility mode for model conversion and optimisation
 
     Returns:
         The path to which the model was written.
